package com.m2pool.pool.strategy;

import com.m2pool.pool.dto.BlockInfoDto;
import com.m2pool.pool.dto.BlockTimeAndNumberDto;
import com.m2pool.pool.mapper.PoolMapper;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Date;
import java.util.List;

/**
 * 旧版
 * 用于获取矿池实际报块一段时间内总数
 * 可能存在无效区块
 */
@Component
public class DetailedBlockDataV1Strategy implements PoolBlockDataStrategy {

    @Resource
    private PoolMapper poolMapper;


    @Override
    public BlockTimeAndNumberDto getTotalBlocks(Date start, Date end,List<BlockInfoDto> blockPerDays ) {

        if (blockPerDays.isEmpty()){
            return BlockTimeAndNumberDto.builder().dateLength(BigDecimal.ZERO).height(0).build();
        }

        long count = blockPerDays.stream()
                .filter(e -> (e.getDate().before(end)))
                .filter(e -> (e.getDate().after(start) || e.getDate().equals(start)))
                .count();

        //每日出块数固定的舍弃
//        BigDecimal nexaCount = PoolCalParamConfig.NEXA.getCount();
        long diffInMillis = end.getTime() - start.getTime();
        BigDecimal dateLength2 = BigDecimal.valueOf(diffInMillis).divide(BigDecimal.valueOf(86400000), 0, RoundingMode.HALF_UP);
        Date poolStart = blockPerDays.get(blockPerDays.size() - 1).getDate();
        //天数不足时，以实际天数计算
        if(poolStart.after(start)){
          dateLength2 = dateLength2.subtract(BigDecimal.valueOf(poolStart.getTime() - start.getTime()).divide(BigDecimal.valueOf(86400000), 2, BigDecimal.ROUND_HALF_UP));
        }
        return BlockTimeAndNumberDto.builder().dateLength(dateLength2).height((int) count).build();
    }
}
